pub fn generate_machines_file_from_healthy(
builders: &[HealthStatus],
) -> Result<String>Expand description
Generate a temporary machines file from healthy builders. Public so the deploy pipeline can call it before building the DAG.
pub fn generate_machines_file_from_healthy(
builders: &[HealthStatus],
) -> Result<String>Generate a temporary machines file from healthy builders. Public so the deploy pipeline can call it before building the DAG.